<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2004 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: Config.php 2155 2005-03-15 18:11:36Z radek $
*/

/**
 * @package    Max
 * @author     Andrew Hill <andrew@awarez.net>
 */

// Required files
require_once 'Config.php';

/**
 * A configuration management class for the Max administration interface.
 */
class MAX_Admin_Config
{
    var $conf;
    
    /**
     * The constructor method. Stores the current parse result of the
     * configuration .ini file so that it can be (locally) modified.
     */
    function MAX_Admin_Config($isNewConfig = false)
    {
        if($isNewConfig) {
            $this->conf = array();
        } else {
            $this->conf = $GLOBALS['_MAX']['CONF'];
        }
    }
    
    /**
     * A method for defining required changes to the Max configuration .ini
     * file.
     *
     * @param string $levelKey The top level of the item in the .ini file.
     * @param string $itemKey The item level of the item in the .ini file
     *                        (under the top level).
     * @param string $value The new value for the item.
     */
    function setConfigChange($levelKey, $itemKey, $value)
    {
        $this->conf[$levelKey][$itemKey] = $value;
    }
    
    /**
     * A method for defining bulk required changes to the Max configuration
     * .ini file.
     *
     * @param string $levelKey The top level of the item in the .ini file.
     * @param array $values The new values for the item.
     */
    function setBulkConfigChange($levelKey, $value)
    {
        $this->conf[$levelKey] = $value;
    }
    
    /**
     * A method for writing out any required changes to the Max
     * configuration .ini file. If successful, re-parses the
     * configuration .ini file, so that the most up-to-date values are used.
     *
     * @param string $configFile  Path to the config file
     * @param boolean $reParse    Is config file should be parsed again
     *
     * @return boolean True when the configuration file was correctly
     *                 written out, false otherwise.
     */
    function writeConfigChange($configFile = null, $reParse = true)
    {
        if(!$configFile) {
            $configFile = MAX_PATH . '/var/max.conf.ini';
        }
        if (MAX_Admin_Config::isConfigWritable($configFile)) {
            $c = new Config();
            $c->parseConfig($this->conf, 'phpArray');
            if ($c->writeConfig($configFile, 'inifile')) {
                if($reParse) {
                    // Re-parse the config file
                    $GLOBALS['_MAX']['CONF'] = @parse_ini_file($configFile, true);
                    $this->conf = $GLOBALS['_MAX']['CONF'];
                    // Set the global $conf value -- normally set by the init
                    // script -- to be the same as $GLOBALS['_MAX']['CONF']
                    global $conf;
                    $conf = $GLOBALS['_MAX']['CONF'];
                }
                return true;
            }
        }
        return false;
    }
    
    /**
     * A method to test if the Max configuration .ini file is writable by
     * the web server process.
     *
     * @static
     *
     * @param string $configFile  Path to the config file
     *
     * @return boolean True if file is writable else method is checking
     *                 if directory is writable (if $checkDir is true)
     *                 else return false
     */
    function isConfigWritable($configFile = null, $checkDir = true)
    {
        if(!$configFile) {
            $configFile = MAX_PATH . '/var/max.conf.ini';
        }
        if (file_exists($configFile)) {
            return is_writable($configFile);
        } elseif ($checkDir) {
            // Max has not been installed yet (or plugin config file doesn't exists)
            // so need to test if the web
            // server can write to the config file directory
            $configDir = substr($configFile, 0, strrpos($configFile, '/'));
            return is_writable($configDir);
        } else {
            return false;
        }
    }
    
}

?>