<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: TestOfMaintenanceStatisticsTracker.php 2024 2005-03-10 17:21:43Z andrew $
*/

/**
 * @package    MaxMaintenance
 * @subpackage TestSuite
 * @author     Andrew Hill <andrew@awarez.net>
 */

require_once MAX_PATH . '/lib/Max.php';
require_once MAX_PATH . '/lib/max/DB.php';
require_once MAX_PATH . '/lib/max/Table/Core.php';
require_once MAX_PATH . '/lib/max/Maintenance/Statistics.php';

/**
 * A class for testing the Maintenance_Statistics_Tracker class.
 */
class Maintenance_TestOfMaintenanceStatisticsTracker extends UnitTestCase
{
    
    /**
     * The constructor method.
     */
    function Maintenance_TestOfMaintenanceStatisticsTracker()
    {        
        $this->UnitTestCase();
    }
    
    /**
     * The main test method.
     */
    function testClass()
    {
        MAX::debug('Running test', PEAR_LOG_INFO);
        // Use a reference to $GLOBALS['_MAX']['CONF'] so that the configuration
        // options can be changed while the test is running
        $conf =& $GLOBALS['_MAX']['CONF'];
        $dbh =& MAX_DB::singleton();
        $tables = MAX_Table_Core::singleton($conf['database']['type'], true);
        // Create the required tables
        $tables->createTable('data_raw_tracker_click');
        $tables->createTable('data_raw_tracker_impression');
        $tables->createTable('data_raw_tracker_variable_value');
        $tables->createTable('log_maintenance_statistics');
        $tables->createTable('userlog');
        // Get the data for the tests
        include_once MAX_PATH . '/lib/max/Maintenance/data/TestOfMaintenanceStatisticsTracker.php';
        // Insert the test data
        $result = $dbh->query(TRACKER_FULL_TEST_TRACKER_IMPRESSIONS);
        $result = $dbh->query(TRACKER_FULL_TEST_TRACKER_VARIABLE_VALUES);
        $result = $dbh->query(TRACKER_FULL_TEST_TRACKER_CLICK);
        // Set up the config as desired for testing
        $conf['maintenance']['operationInterval'] = 60;
        $conf['maintenance']['compactStats'] = false;
        $conf['modules']['Tracker'] = true;
        $conf['table']['split'] = false;
        // Create an appropriate Maintenance_Statistics class
        $maintenanceStatistics = Maintenance_Statistics::instance('Tracker', 
                                         new Date('2004-11-26 14:00:00'),
                                         null, true);
        // Step 1: Summarise raw data into the intermediate tables
        $maintenanceStatistics->summariseIntermediate();
        // Step 2: Summarise intermediate data into summary tables
        $maintenanceStatistics->summariseFinal();
        // Step 3: Delete old raw data that has been summarised
        $maintenanceStatistics->deleteOldData();
        // Step 4: Update the log tables detailing the maintenance statistics run
        $maintenanceStatistics->logCompletion();  
        // Test the results
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_tracker_impression']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_tracker_variable_value']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_tracker_click']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 30);
        // Drop the tables
        $tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_tracker_click']);
        $tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_tracker_impression']);
        $tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_tracker_variable_value']);
        $tables->dropTable($conf['table']['prefix'].$conf['table']['log_maintenance_statistics']);
        $tables->dropTable($conf['table']['prefix'].$conf['table']['userlog']);
    }
    
}

?>
