<?php

    require_once MAX_PATH . '/lib/max/Plugins/FileScanner.php';

    define('MAX_FILE_TEST_DIR', dirname(__FILE__).'/testdir');

    class TestOfFileScanner extends UnitTestCase {
        
        function TestOfFileScanner() {
            $this->UnitTestCase('FileScanner test');
        }

        function testFileScanner() {
            $fs = new Max_Plugins_FileScanner();
            
            $this->assertIdentical($fs->getFileExtension('test.php'), 'php');
            
            $fs->addFileTypes(array('php','inc'));
            $this->assertIdentical($fs->isAllowedFile('test.php'), TRUE);
            $this->assertIdentical($fs->isAllowedFile('test.inc'), TRUE);

            $this->assertIdentical($fs->getAllFiles(), array());
            $fs->addFile('test.php');
            $this->assertIdentical($fs->getAllFiles(), array('test.php'));
            $fs->addFile('test2.plugin.php');
            $this->assertIdentical($fs->getAllFiles(), array('test.php','test2.plugin.php'));
            $fs->addFile('test.inc');
            $this->assertIdentical($fs->getAllFiles(), array('test.inc','test.php','test2.plugin.php'));
            $fs->addFile('test.gif');
            $this->assertIdentical($fs->getAllFiles(), array('test.inc','test.php','test2.plugin.php'));
        }

        function testAddDir() {
            $fs = new Max_Plugins_FileScanner();
            $fs->addFileTypes(array('php','inc'));
            $fs->addDir(MAX_FILE_TEST_DIR);
            $this->assertIdentical($fs->getAllFiles(),
                    array(
                        MAX_FILE_TEST_DIR.'/test.inc',
                        MAX_FILE_TEST_DIR.'/test.plugin.php',
                        MAX_FILE_TEST_DIR.'/translation.php',
                    )
                );
            
            $fs->reset();
            $fs->addDir(MAX_FILE_TEST_DIR, $recursive = true);
            $this->assertIdentical($fs->getAllFiles(), 
                    array(
                        MAX_FILE_TEST_DIR.'/subdir/test2.plugin.php', 
                        MAX_FILE_TEST_DIR.'/test.inc', 
                        MAX_FILE_TEST_DIR.'/test.plugin.php',
                        MAX_FILE_TEST_DIR.'/translation.php',
                    )
                );
        }

        function testFileMaskAndSubdir() {
            $fs = new Max_Plugins_FileScanner();
            $fs->addFileTypes(array('php', 'inc'));
            $fs->setFileMask('^([a-zA-Z0-9\-\.\\:/]*)\.plugin\.php$');
            $fs->addDir(MAX_FILE_TEST_DIR);
            $this->assertIdentical($fs->getAllFiles(), array(MAX_FILE_TEST_DIR.'/test.plugin.php'));
        }

    }

?>