<?php

    class TestErrorHandler {
        function handleErrors() {
        }
    }
    
    require_once(MAX_PATH . '/lib/max/Plugins/Plugins.php');

    define('MAX_PLUGINS_TEST_DIR', dirname(__FILE__).'/testdir');

    class TestOfPlugins extends UnitTestCase {
        
        function TestOfPlugins() {
            $this->UnitTestCase('Plugins test');
        }

        function testFactory() {
            
        }
        
        function testGetConfigByFileNameErrors() {
            // file doesn't exists
            Mock::generate('TestErrorHandler');
            $testErrorHandler = new MockTestErrorHandler($this);
            
            PEAR::setErrorHandling(PEAR_ERROR_CALLBACK, array(&$testErrorHandler, 'handleErrors'));
            $testErrorHandler->expectOnce('handleErrors');
            
            $ret = Max_Plugins::getConfigByFileName('someTestFileWhichDoesntExists.conf.ini');
            $this->assertIdentical($ret, false);
            
            $testErrorHandler->tally();
        }

        function testGetConfigByFileName() {
            $expectedArray = array(
                'key1' => 'val1',
                'key2' => 'val2',
            );
            $ret = Max_Plugins::getConfigByFileName(MAX_PLUGINS_TEST_DIR . '/plugin.conf.ini');
            $this->assertIdentical($ret, $expectedArray);
            
            $expectedMultiDimensionalArray = array(
                'section_1' => $expectedArray,
                'section_2' => array('key3' => 'val3'),
            );
            $ret = Max_Plugins::getConfigByFileName(MAX_PLUGINS_TEST_DIR . '/plugin2.conf.ini', $multiDimensional = true);
            $this->assertIdentical($ret, $expectedMultiDimensionalArray);
        }

        /**
         * something is wrong with mock objects...
         */
        function _REPAIR_ME_testConfig() {
            Mock::generate('Max_Plugins');
            
            $module = 'moduleName';
            $package = 'packageName';
            $processSections = false;
            
            $mockPlugin = &new MockMax_Plugins($this);
            $mockPlugin->setReturnValue('getConfigByFileName', true);
            
            $mockPlugin->expectOnce('getConfigByFileName');
            /*
                array(MAX_PATH . "/plugins/{$module}/{$package}/plugin.conf.ini", 
                $processSections)
            */
            $ret = $mockPlugin->getConfig($module, $package, null, $commonPackageConfig = true, $processSections);
            $this->assertIdentical($ret, true);
            $mockPlugin->tally();
        }
        
        function testGetPluginsFromFolder() {
            $pluginFiles = Max_Plugins::getPluginsFilesFromFolder(MAX_PLUGINS_TEST_DIR, $recursive = false);
            $this->assertIdentical($pluginFiles, array('testdir:test' => MAX_PLUGINS_TEST_DIR.'/test.plugin.php'));
            
            $pluginFiles = Max_Plugins::getPluginsFilesFromFolder(MAX_PLUGINS_TEST_DIR, $recursive = true);
            $this->assertIdentical($pluginFiles, 
                array(
                    'subdir:test2' => MAX_PLUGINS_TEST_DIR.'/subdir/test2.plugin.php',
                    'testdir:test' => MAX_PLUGINS_TEST_DIR.'/test.plugin.php'
                )
            );
        }

        function testGetPlugins() {
            $plugins = Max_Plugins::getPlugins('geotargeting', null, $recursive = 1);
            
            // it's quite difficult to test so we are using just print_r to test it
            /*
            echo '<pre>';
            print_r($plugins);
            echo '</pre>';
            */
        }

        /**
         * TODO: upgrade simpletest
         */
        function _REPAIR_ME_testGetPlugins() {
            Mock::generate('Max_Plugins');
            $mockPlugins = new MockMax_Plugins($this);
            $mockPlugins->setReturnValue('getPluginsFromFolder', true);

            $recursive = true;
            $mockPlugins->expectOnce('getPluginsFromFolder', array(MAX_PATH.'/plugins/moduleName/packageName', $recursive));
            $ret = $mockPlugins->getPlugins('moduleName', 'packageName', $recursive);
            $mockPlugins->tally();
        }

    }

?>