<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: TestOfAdminDA.php 2229 2005-03-18 16:03:38Z andrew $
*/

/**
 * @package    MaxDal
 * @subpackage TestSuite
 * @author     Demian Turner <demian@awarez.net>
 */

require_once MAX_PATH . '/lib/max/Admin_DA.php';
require_once 'Text/Password.php';

/**
 * A class for testing the Admin_DA class.
 */
class Admin_DaTest extends UnitTestCase
{
    // +---------------------------------------+
    // | Utility methods                       |
    // |                                       |
    // | for db connections and last inserted  |
    // | IDs                                   |
    // +---------------------------------------+
    var $dbh = null;

    function Admin_DaTest()
    {
        $this->dbh =& MAX_DB::singleton();
    }
    
    function getLastRecordInserted($tableName, $tableIndexField)
    {  
        $tableName = $conf['table']['prefix'] . $tableName;
        $sql = "SELECT MAX($tableIndexField) AS max FROM $tableName";
        $result = $this->dbh->getRow($sql, array(), DB_FETCHMODE_ASSOC);
        
        return (int) $result['max'];
    }
    
    // +---------------------------------------+
    // | Test relational/constraint-related    |
    // | private methods                       |
    // +---------------------------------------+    
    
    function test_getStatsColumns()
    {
        $entities = array(
         'ad',
         'advertiser',
         'agency',
         'placement',
         'publisher',
         'zone',
         );    
        foreach ($entities as $entity) {
            $ret = Admin_DA::_getStatsColumns($entity);
            $this->assertTrue(is_array($ret));
            $this->assertEqual(count($ret), 5); //  each hash should have 5 elements
            $lastElement = array_pop($ret);
             //   last element should be the entity_id
            $this->assertEqual($entity . '_id', $lastElement);
        }
    }
    
    function test_getColumns()
    {
        //  load hash representing data structure
        require MAX_PATH . '/lib/max/data/data.entities.php';
        foreach ($entities as $entity => $hash) {    
            $ret = Admin_DA::_getColumns($entity, true);
            $this->assertIdentical($hash, $ret);            
        }
    }
    
    function test_getPrimaryTable()
    {
        require MAX_PATH . '/lib/max/data/data.entities.php';
        foreach ($entities as $entity => $hash) {    
            $ret = Admin_DA::_getPrimaryTable($entity);
            $this->assertTrue(is_array($ret));
            $this->assertTrue(count($ret) == 1);
            $keys = array_keys($ret);
            $vals = array_values($ret);
            $this->assertTrue(!is_nan($keys[0]));
            $this->assertTrue(!is_null($vals[0]));            
        }    
    }
    
    function test_getTables()
    {
        require MAX_PATH . '/lib/max/data/data.entities.php';
        foreach ($entities as $entity => $hash) {    
            $ret = Admin_DA::_getTables($entity);
            $this->assertTrue(is_array($ret));
            $this->assertTrue(count($ret) == 1);
            $keys = array_keys($ret);
            $vals = array_values($ret);
            $this->assertTrue(!is_nan($keys[0]));
            $this->assertTrue(!is_null($vals[0]));
        }    
    }
    
    function test_getLimitations()
    {
        require MAX_PATH . '/lib/max/data/data.entities.php';
        foreach ($entities as $entity => $hash) {
            $ret = Admin_DA::_getLimitations($entity, array_flip($hash));
            $this->assertTrue(is_array($ret));            
        }
        
    }
    
    // +---------------------------------------+
    // | Test SQL-related private methods      |
    // |                                       |
    // +---------------------------------------+
    function test_insert()
    {
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName);
        
        $aTable = array('zones' => 'foo');
        $aVariables = array(
            'affiliateid' => 23,
            'zonename' => 'foo',
            'description' => 'this is the desc');
        $ret = Admin_DA::_insert($aTable, $aVariables);
        $this->assertTrue(is_int($ret));
        $this->assertTrue($ret > 0);
        
        $this->dbh->rollback($transactionName);     
        
    }
    
    function test_select()
    {       
    }    
    
//    $aActiveAdvertisers = Admin_DA::_getEntities('advertiser', $aParams
       
    
    // +---------------------------------------+
    // | Test public methods                   |
    // |                                       |
    // +---------------------------------------+   
        
    function testAddPlacementZone()
    {
        // starting the transaction or subtransaction
        // for details look at lib/pear/DB/mysql_SGL.php    
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName);
           
        $ret = Admin_DA::addPlacementZone(array('zone_id' => 1, 'placement_id' => 2));
        $this->assertTrue(is_int($ret));
        $this->assertTrue($ret > 0);
        
        $this->dbh->rollback($transactionName);          
    }
    
    // +---------------------------------------+
    // | limitations                           |
    // +---------------------------------------+     
    function testGetLimitations()
    {
        //  FIXME: needs real data
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName);  
           
        $ret = Admin_DA::getLimitations(array('zone_id' => 1, 'placement_id' => 2));
        $this->assertTrue(is_array($ret));
        
        $this->dbh->rollback($transactionName);
    }
    
    function testAddLimitation()
    {
        //  a bug with transactions causes this valid insert to fail        
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName);     
        $ret = Admin_DA::addLimitation(array(
            'bannerid' => rand(1,999), 
            'executionorder' => rand(1,9),
            'logical' => 'and',
            'type' => 'foo',
            ));
        $this->assertTrue(is_int($ret));
        $this->dbh->rollback($transactionName);          
    }
    
    // +---------------------------------------+
    // | variables                             |
    // +---------------------------------------+     
    function testGetVariables()
    {
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName);
            
        $ret = Admin_DA::addVariable(array(
            'trackerid' => rand(1,999), 
            'name' => 'foo',
            'description' => 'bar',
            'datatype' => 'string',
            'is_basket_value' => rand(1,9999),
            ));
        $this->assertTrue(is_int($ret)); 
        $retVar = Admin_DA::getVariables(array('variableid' => $ret));
        /*
        Array
        (
            [58] => Array
                (
                    [variable_id] => 58
                    [tracker_id] => 520
                    [name] => foo
                    [type] => string
                )
        
        )
        */
        $this->assertTrue(is_array($retVar[$ret]));        
        $this->dbh->rollback($transactionName);
    }
    
    function testAddVariable()
    {
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName);
           
        $ret = Admin_DA::addVariable(array(
            'trackerid' => rand(1,999), 
            'name' => 'foo',
            'description' => 'bar',
            'datatype' => 'string',
            'is_basket_value' => rand(1,9999),
            ));
        $this->assertTrue(is_int($ret));
        $this->assertTrue($ret > 0);
        
        $this->dbh->rollback($transactionName);
    }   
    
    // +---------------------------------------+
    // | trackers                              |
    // +---------------------------------------+
    function testGetTracker()
    {
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName);

        $id = Admin_DA::addTracker(array(
            'trackername' => 'foo', 
            'description' => 'bar',
            'clientid' => rand(1,9999),
            ));

        $ret = Admin_DA::getTracker($id);
        // should look like this
        /*
        Array
        (
            [advertiser_id] => 123
            [tracker_id] => 11
            [name] => sdfasdf
            [description] => desc
            [viewwindow] => 22
            [clickwindow] => 33
            [blockwindow] => 55
        )
        */
        $this->assertTrue(is_array($ret));
        $this->assertTrue(count($ret));
        $this->assertTrue(array_key_exists('advertiser_id', $ret));
        $this->assertTrue(array_key_exists('tracker_id', $ret));
        $this->assertTrue(array_key_exists('name', $ret));
        $this->assertTrue(array_key_exists('description', $ret));
        $this->assertTrue(array_key_exists('viewwindow', $ret));
        $this->assertTrue(array_key_exists('clickwindow', $ret));
        $this->assertTrue(array_key_exists('blockwindow', $ret));
        
        $this->dbh->rollback($transactionName);        
    }
        
    function testAddTracker()
    {
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName);
           
        $ret = Admin_DA::addTracker(array(
            'trackername' => 'foo', 
            'description' => 'bar',
            'clientid' => rand(1,9999),
            ));
        $this->assertTrue(is_int($ret));
        $this->assertTrue($ret > 0);
        
        $this->dbh->rollback($transactionName);
    }
    
    function testDuplicateTracker()
    {
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName);  
            
        $trackerId = Admin_DA::addTracker(array(
            'trackername' => 'foo', 
            'description' => 'bar',
            'clientid' => rand(1,9999),
            ));
        $this->assertTrue(is_int($trackerId));
        $this->assertTrue($trackerId > 0);            
            
        $tracker1 = Admin_DA::getTracker($trackerId);             
        
        $ret = Admin_DA::duplicateTracker($trackerId);
        $this->assertTrue(is_int($ret));
        $this->assertTrue($ret > 0); 
                
        $tracker2 = Admin_DA::getTracker($trackerId);                        
        $this->assertTrue(is_array($tracker2));
        $this->assertTrue(count($ret));
                
        //  compare two trackers
        $this->assertEqual($tracker1, $tracker2);
        
        $this->dbh->rollback($transactionName);
    }    
    // +---------------------------------------+
    // | placements                            |
    // +---------------------------------------+
    function testGetPlacement()
    {
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName); 
        $id = Admin_DA::addPlacement(array(
            'campaignname' => 'foo', 
            'clientid' => rand(1,9999),
            'views' => rand(1,9999),
            'clicks' => rand(1,9999),
            'conversions' => rand(1,9999),
            ));

        $ret = Admin_DA::getPlacement($id);

        // should look like this
        /*
        Array
        (
            [advertiser_id] => 123
            [placement_id] => 1
            [name] => mycampaign
            [active] => t
            [views] => -1
            [clicks] => -1
            [conversions] => -1
            [expire] => 2005-11-01
            [activate] => 0000-00-00
            [priority] => l
            [weight] => 1
            [target] => 0
            [optimise] => f
            [anonymous] => f
        )
        */
        $this->assertTrue(is_array($ret));
        $this->assertTrue(count($ret));
        $this->assertTrue(array_key_exists('advertiser_id', $ret));
        $this->assertTrue(array_key_exists('placement_id', $ret));
        $this->assertTrue(array_key_exists('name', $ret));
        $this->assertTrue(array_key_exists('active', $ret));
        $this->assertTrue(array_key_exists('views', $ret));
        $this->assertTrue(array_key_exists('clicks', $ret));
        $this->assertTrue(array_key_exists('conversions', $ret));
        $this->assertTrue(array_key_exists('expire', $ret));
        $this->assertTrue(array_key_exists('activate', $ret));
        $this->assertTrue(array_key_exists('priority', $ret));
        $this->assertTrue(array_key_exists('weight', $ret));
        $this->assertTrue(array_key_exists('target', $ret));
        $this->assertTrue(array_key_exists('optimise', $ret));
        $this->assertTrue(array_key_exists('anonymous', $ret));
        
        $this->dbh->rollback($transactionName);
    }
    
    function testDuplicatePlacement()
    {
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName);  
            
        $placementId = Admin_DA::addPlacement(array(
            'campaignname' => 'foo', 
            'clientid' => rand(1,9999),
            'views' => rand(1,9999),
            'clicks' => rand(1,9999),
            'conversions' => rand(1,9999),
            ));
        $this->assertTrue(is_int($placementId));
        $this->assertTrue($placementId > 0);         
            
        $placement1 = Admin_DA::getPlacement($placementId);
        
        $ret = Admin_DA::duplicatePlacement($placementId);
        $this->assertTrue(is_int($ret));
        $this->assertTrue($ret > 0); 
                
        $placement2 = Admin_DA::getPlacement($ret);                        
        $this->assertTrue(is_array($placement2));
        $this->assertTrue(count($placement2));
                
        //  compare two placements
        unset($placement1['placement_id']);
        unset($placement2['placement_id']);
        unset($placement1['name']);
        unset($placement2['name']);        
        $this->assertEqual($placement1, $placement2);
        
        $this->dbh->rollback($transactionName);        
    }
    // +---------------------------------------+
    // | agencies                              |
    // +---------------------------------------+
    function testGetAgency()
    {
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName);  
            
        $id = Admin_DA::addAgency(array(
            'name' => 'foo', 
            'contact' => 'bar',
            'username' => 'user',
            'email' => 'agent@example.com',
            ));

        $ret = Admin_DA::getAgency($id);

        // should look like this
        /*
        Array
        (
            [agency_id] => 1
            [name] => my agency
            [contact] => foo bar
            [email] => foo@example.com
            [username] => Ronald
            [password] => Reagan
            [permissions] => 33
            [language] => chinese
        )
        */
        $this->assertTrue(is_array($ret));
        $this->assertTrue(count($ret));
        $this->assertTrue(array_key_exists('agency_id', $ret));
        $this->assertTrue(array_key_exists('name', $ret));
        $this->assertTrue(array_key_exists('contact', $ret));
        $this->assertTrue(array_key_exists('email', $ret));
        
        $this->dbh->rollback($transactionName);
    }
    
    function testGetAgencies()
    {
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName);  
            
        $id = Admin_DA::addAgency(array(
            'name' => 'foo', 
            'contact' => 'bar',
            'username' => 'user',
            'email' => 'agent@example.com',
            ));

        $agencies = Admin_DA::getAgencies(array('agency_id' => $id));
        $this->assertTrue(count($agencies) == 1);
        $aKey = array_keys($agencies);
        $id = $aKey[0];
        $this->assertTrue(is_int($id));
        $this->assertTrue(is_array($agencies[$id]));
        $this->assertTrue(array_key_exists('agency_id', $agencies[$id]));
        $this->assertTrue(array_key_exists('name', $agencies[$id]));
        
        $this->dbh->rollback($transactionName);

    }    
    // +---------------------------------------+
    // | advertisers                           |
    // +---------------------------------------+

    // +---------------------------------------+
    // | ads                                   |
    // +---------------------------------------+
    // FIMXE: do duplicate and add methods
    function testGetAd()
    {
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName);  
            
        $id = Admin_DA::addAd(array(
            'campaignid' => rand(1, 999), 
            'active' => 't',
            'contenttype' => 'gif',
            'pluginversion' => rand(1, 999),
            ));

        $ret = Admin_DA::getAd($id);
        // should look like this
        /*
        Array
        (
            [ad_id] => 1
            [placement_id] => 234234
            [active] => t
            [name] => desc
            [type] => sql
            [contenttype] => gif
            [pluginversion] => 1
            [filename] => sdfasdf
            [imageurl] => http://img.com
            [htmltemplate] => foo
            [htmlcache] => bar
            [width] => 5
            [height] => 6
            [weight] => 3
            [seq] => 1
            [target] => 
            [url] => http://localhost/phpMyAdmin/
            [alt] => 
            [status] => 
            [bannertext] => asdasdfad
            [autohtml] => t
            [adserver] => 
            [block] => 0
            [capping] => 0
            [session_capping] => 0
            [compiledlimitation] => asdfasdf
            [append] => asdfasdf
            [appendtype] => 1
            [bannertype] => 2
            [alt_filename] => 
            [alt_imageurl] => 
            [alt_contenttype] => gif
        )
        */
        $this->assertTrue(is_array($ret));
        $this->assertTrue(count($ret));
        $this->assertTrue(array_key_exists('ad_id', $ret));
        $this->assertTrue(array_key_exists('placement_id', $ret));
        $this->assertTrue(array_key_exists('active', $ret));
        $this->assertTrue(array_key_exists('name', $ret));
        $this->assertTrue(array_key_exists('type', $ret));
        $this->assertTrue(array_key_exists('contenttype', $ret));
        $this->assertTrue(array_key_exists('pluginversion', $ret));
        $this->assertTrue(array_key_exists('filename', $ret));
        $this->assertTrue(array_key_exists('imageurl', $ret));
        $this->assertTrue(array_key_exists('htmltemplate', $ret));
        $this->assertTrue(array_key_exists('htmlcache', $ret));
        $this->assertTrue(array_key_exists('width', $ret));
        $this->assertTrue(array_key_exists('height', $ret));
        $this->assertTrue(array_key_exists('weight', $ret));
        $this->assertTrue(array_key_exists('seq', $ret));
        $this->assertTrue(array_key_exists('target', $ret));
        $this->assertTrue(array_key_exists('url', $ret));
        $this->assertTrue(array_key_exists('alt', $ret));
        $this->assertTrue(array_key_exists('status', $ret));
        $this->assertTrue(array_key_exists('bannertext', $ret));
        $this->assertTrue(array_key_exists('autohtml', $ret));
        $this->assertTrue(array_key_exists('adserver', $ret)); 
        $this->assertTrue(array_key_exists('block', $ret));
        $this->assertTrue(array_key_exists('capping', $ret));
        $this->assertTrue(array_key_exists('session_capping', $ret));
        $this->assertTrue(array_key_exists('compiledlimitation', $ret));
        $this->assertTrue(array_key_exists('append', $ret));
        $this->assertTrue(array_key_exists('appendtype', $ret));
        $this->assertTrue(array_key_exists('bannertype', $ret));
        $this->assertTrue(array_key_exists('alt_filename', $ret));
        $this->assertTrue(array_key_exists('alt_imageurl', $ret)); 
        $this->assertTrue(array_key_exists('alt_contenttype', $ret));
        
        $this->dbh->rollback($transactionName);
    }
    
    // +---------------------------------------+
    // | zones                                 |
    // +---------------------------------------+
    function testAddZone()
    {
        $name = & new Text_Password();          
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName);
               
        $ret = Admin_DA::addZone(array(
            'publisher_id' => rand(1, 999),
            'type' => rand(0, 4),
            'name' => $name->create(),
            ));
        $this->assertTrue(is_int($ret));
        $this->assertTrue($ret > 0);
        
        $this->dbh->rollback($transactionName);        
    } 

    function testGetZone()
    {
        $conf = $GLOBALS['_MAX']['CONF'];

        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName);
               
        $id = Admin_DA::addZone(array(
            'publisher_id' => rand(1, 999),
            'type' => rand(0, 4),
            'name' => 'quux',
            ));
        $this->assertTrue(is_int($id));
        $this->assertTrue($id > 0);
        
        //  get zone record as control element     
        $query = 'SELECT * FROM '.$conf['table']['prefix'].'zones WHERE zoneid = ' . $id;
        $aZone1 = $this->dbh->getRow($query);
        $this->assertTrue(is_array($aZone1));
        
        //  massage results so as to be comparable with Admin_DA::getZone()
        Admin_DA::_switch($aZone1, 'affiliateid', 'publisher_id');
        Admin_DA::_switch($aZone1, 'zonename', 'name');
        Admin_DA::_switch($aZone1, 'delivery', 'type');
        Admin_DA::_switch($aZone1, 'zoneid', 'zone_id'); 
        unset($aZone1['zonetype']);       
        $aZone1 = array_filter($aZone1, 'strlen');        
                
        $aZone2 = Admin_DA::getZone($id);

        /*
        Array
        (
            [zone_id] => 80
            [publisher_id] => 508
            [name] => toufreacli
            [type] => 3
            [description] => 
            [width] => 0
            [height] => 0
            [chain] => 
            [prepend] => 
            [append] => 
            [appendtype] => 0
            [forceappend] => f
        )
        */
                
        $this->assertTrue(is_array($aZone2)); 
        $this->assertTrue(count($aZone2) > 0);
        $this->assertTrue(array_key_exists('zone_id', $aZone2));
        $this->assertTrue(array_key_exists('publisher_id', $aZone2));
        $this->assertTrue(array_key_exists('name', $aZone2));
        $this->assertTrue(array_key_exists('description', $aZone2));
        $this->assertTrue(array_key_exists('width', $aZone2));
        $this->assertTrue(array_key_exists('height', $aZone2));
        $this->assertTrue(array_key_exists('chain', $aZone2));
        $this->assertTrue(array_key_exists('prepend', $aZone2));
        $this->assertTrue(array_key_exists('append', $aZone2));
        $this->assertTrue(array_key_exists('appendtype', $aZone2));
        $this->assertTrue(array_key_exists('forceappend', $aZone2));

        $aZone2 = array_filter($aZone2, 'strlen');
        $this->assertEqual($aZone1, $aZone2);
        
        $this->dbh->rollback($transactionName);
    }
    
    //  FIXME: why does getZones() have a v. different return type
    //  from getZone()?
    function testGetZones()
    {
        $conf = $GLOBALS['_MAX']['CONF'];
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName);
               
        $ret = Admin_DA::addZone(array(
            'publisher_id' => rand(1, 999),
            'type' => rand(0, 4),
            'name' => 'quux',
            ));
        $this->assertTrue(is_int($ret));
        $this->assertTrue($ret > 0);
        
        //  get zone record as control element     
        $query = 'SELECT * FROM '.$conf['table']['prefix'].'zones WHERE zoneid = ' . $ret;
        $aZone1 = $this->dbh->getRow($query);
        $this->assertTrue(is_array($aZone1));
        
        //  massage results so as to be comparable with Admin_DA::getZone()
        Admin_DA::_switch($aZone1, 'affiliateid', 'publisher_id');
        Admin_DA::_switch($aZone1, 'zonename', 'name');
        Admin_DA::_switch($aZone1, 'delivery', 'type');
        Admin_DA::_switch($aZone1, 'zoneid', 'zone_id'); 
        unset($aZone1['zonetype']);
        unset($aZone1['appendtype']);
        unset($aZone1['forceappend']);
        unset($aZone1['height']);
        unset($aZone1['width']);
        $aZone1 = array_filter($aZone1, 'strlen');        
                
        $aZone2 = Admin_DA::getZones(array('zone_id' => $ret));
        /*
        Array
        (
            [80] => Array
                (
                    [zone_id] => 80
                    [publisher_id] => 508
                    [name] => toufreacli
                    [type] => 3
                )
        
        )
        */

        $this->assertTrue(is_array($aZone2[$ret])); 
        $aZone2 = array_filter($aZone2, 'strlen');
        $this->assertEqual($aZone1, $aZone2[$ret]);
        
        $this->dbh->rollback($transactionName);    
    }

    function testDuplicateZone()
    {
        $conf = $GLOBALS['_MAX']['CONF'];
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName);
               
        $id = Admin_DA::addZone(array(
            'publisher_id' => rand(1, 999),
            'type' => rand(0, 4),
            'name' => 'quux',
            ));
        $this->assertTrue(is_int($id));
        $this->assertTrue($id > 0);
        
        //  get zone record as control element     
        $query = 'SELECT * FROM '.$conf['table']['prefix'].'zones WHERE zoneid = ' . $id;
        $aZone1 = $this->dbh->getRow($query);
        $this->assertTrue(is_array($aZone1));
             
        
        $ret = Admin_DA::duplicateZone($id);                
        $this->assertTrue(is_int($ret));
        $this->assertTrue($ret > 0);
        
        $query = 'SELECT * FROM '.$conf['table']['prefix'].'zones WHERE zoneid = ' . $ret;
        $aZone2 = $this->dbh->getRow($query);
        $this->assertTrue(is_array($aZone2));
                
        //  unset zoneid and name as these are unique
        unset($aZone1['zoneid']);
        unset($aZone2['zoneid']);
        unset($aZone1['zonename']);
        unset($aZone2['zonename']);
        $this->assertEqual($aZone1, $aZone2);
        
        $this->dbh->rollback($transactionName);        
    }
    
    function testAddCategory()
    {
        $name = & new Text_Password();
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName);               
        
        $ret = Admin_DA::addCategory(array('name' => $name->create()));
        $this->assertTrue(is_int($ret));
        $this->assertTrue($ret > 0);
        
        $this->dbh->rollback($transactionName);        
    }    

    function testAddAdCategory()
    {
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName); 
                
        $ret = Admin_DA::addAdCategory(array('ad_id' => 1, 'category_id' => 2));
        $this->assertTrue(is_int($ret));
        $this->assertTrue($ret > 0);
        
        $this->dbh->rollback($transactionName);         
    }
    
    function testAddAdZone()
    {
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName); 
                
        $ret = Admin_DA::addAdZone(array('zone_id' => 1, 'ad_id' => 2));
        $this->assertTrue(is_int($ret));
        $this->assertTrue($ret > 0);
        
        $this->dbh->rollback($transactionName);         
    }
    
    function testDeleteImage()
    {
        //  this test fails on the _getLimitations and the method
        //  also doesn't seem to be called anywhere
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
#        $this->dbh->startTransaction($transactionName);
#        $ret = Admin_DA::_deleteEntity('image', 1);        
    }
    
    // +---------------------------------------+
    // | Test stats methods                    |
    // |                                       |
    // +---------------------------------------+     
    function testGetPlacementsStats()
    {
        //  FIXME: needs real data
        $transactionName = uniqid(__CLASS__.__FUNCTION__, true);
        $this->dbh->startTransaction($transactionName); 
                
        $ret = Admin_DA::getPlacementsStats(array('advertiser_id' => 1));
        $this->assertTrue(is_array($ret));
        
        $this->dbh->rollback($transactionName);         
    }
        
    // +---------------------------------------+
    // | Test helper methods                   |
    // |                                       |
    // +---------------------------------------+
    function test_Switch()
    {
        $input = array(
            'fooName' => 'fooValue',
            'barName' => 'barValue');
        $name = 'fooName';
        $legacyName = 'replacedFooName';
        $output = $input;
        Admin_DA::_switch(&$output, $name, $legacyName);

        //  determine that the desired field name has been removed
        $this->assertTrue(!array_key_exists($name, $output));
        
        //  determine that the legacy name has been inserted
        $this->assertTrue(array_key_exists($legacyName, $output));
        
        //  make sure extra keys not altered
        $this->assertTrue(array_key_exists('barName', $output)); 
        
        //  make sure existing value has new key     
        $this->assertEqual('fooValue', $output[$legacyName]);
        
        //  assert key swapped successfully
        $this->assertEqual($input[$name], $output[$legacyName]);        
    }
    
    function test_getUniqueName()
    {
        $entities = array();
        for ($x = 0; $x < 20; $x++) {
            $entities[] = array('name' => 'foo_' . $x);
        }
        $control = array('name' => 'foo_7');
        $orig = $control;
        Admin_DA::_getUniqueName($control, $entities, 'copy');
        $this->assertTrue(is_array($control));
        $this->assertTrue(array_key_exists('name', $control));                  
        $this->assertNotEqual($orig, $control);
    }
}

?>
