<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.2                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| Copyright (c) 2000-2003 the phpAdsNew developers                          |
| For contact details, see: http://www.phpadsnew.com/                       |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: campaigndelivery.plugin.php 2228 2005-03-18 15:57:40Z andrew $
*/

/**
 * @package    MaxPlugins
 * @subpackage Reports
 * @author     Misza Pawlowski <michal@awarez.net>
 * @author     Radek Maciaszek <radek@awarez.net>
 */

require_once MAX_PATH . '/plugins/reports/Reports.php';

class Plugins_Reports_Agency_Campaigndelivery extends Plugins_Reports {
    
    // Public info function
    function info()
    {
    	global $strPluginCampaignDelivery, $strDelimiter, $strDate;
    	
    	include_once MAX_PATH . '/lib/max/Plugins/PluginTranslation.php';
        Max_PluginTranslation::init($this->module, $this->package);
        
    	$plugininfo = array (
    		"plugin-name"			=> Max_PluginTranslation::translate('Campaign Delivery Report', $this->module, $this->package),
    		"plugin-description"	=> Max_PluginTranslation::translate('Trafficking report which shows all campaign activity for '.
    		                          'a given day, including how well it met its delivery targets.',
    		                          $this->module, $this->package),
    		'plugin-category'     => 'agency',
    		'plugin-category-name'	=> Max_PluginTranslation::translate('Agency Reports', $this->module, $this->package),
    		"plugin-author"			=> "Chris Nutting",
    		"plugin-export"			=> "csv",
    		"plugin-authorize"		=> phpAds_Admin+phpAds_Agency,
    		"plugin-import"			=> array (
    			"delimiter"		=> array (
    				"title"					=> $strDelimiter,
    				"type"					=> "edit",
    				"size"					=> 1,
    				"default"				=> "," 
    				),
    			"stats_date"		=> array (
    				"title"				=> $strDate,
    				"type"				=> "edit",
    				"size"				=> 10,
    				"default"			=> date("Y/m/d", (time() - (24*60*60))), 
    				)
    			)
    		);
    	
    	return ($plugininfo);
    }
    
    
    
    /*-------------------------------------------------------*/
    /* Private plugin function                               */
    /*-------------------------------------------------------*/
    
    function execute($delimiter=",", $stats_date)
    {
        $conf = $GLOBALS['_MAX']['CONF'];
        
    	global $date_format;
    	global $strCampaign, $strTotal, $strDay, $strViews, $strClicks, $strCTRShort, $strConversions, $strCNVRShort;
    	
    	// Format the start and end dates
        $dbStart = date("Y-m-d", strtotime($start));
        $dbEnd   = date("Y-m-d", strtotime($end));
        $start = date("Y/m/d", strtotime($start));
        $end   = date("Y/m/d", strtotime($end));
    	
    	
    	$clientid = phpAds_getUserID();
    	//$yesterday = date("Ymd", (time() - 24*60*60));
    	$stats_date = str_replace("/", "", $stats_date);
    	
    	header ("Content-type: application/csv\nContent-Disposition: inline; filename=CampaignDelivery_".$stats_date.".csv");
    	
    	$res_query = "
    		SELECT a.name AS agency,
    		 		cl.clientname AS advertiser,
    		 		c.campaignname AS campaign,
    		 		t.campaignid,
    		 		c.views AS remaining_views,
    		 		c.activate AS start_date,
    		 		c.expire AS end_date,
    		 		t.target,
    		 		t.views,
    		 		((t.views / t.target) * 100) AS ratio
    		FROM 
    				".$conf['table']['prefix'].$conf['table']['targetstats']." AS t,
    				".$conf['table']['prefix'].$conf['table']['campaigns']." AS c,
    				".$conf['table']['prefix'].$conf['table']['clients']." AS cl,
    				".$conf['table']['prefix'].$conf['table']['agency']." AS a
    		WHERE 
    				a.agencyid=cl.agencyid 
    				AND c.clientid=cl.clientid 
    				AND t.campaignid=c.campaignid 
    				AND t.day=".$stats_date."
    	";
    	
    	$res_query .= (phpAds_isUser(phpAds_Client)) ? " AND c.clientid = ".$clientid : '';
    	$res_query .= (phpAds_isUser(phpAds_Agency)) ? " AND a.agencyid = ".$clientid : '';
    	
    	$res_query .= "
    	ORDER BY a.agencyid ASC, ratio DESC
    	";
    	
    	$res_banners = phpAds_dbQuery($res_query) or phpAds_sqlDie();
    
    	echo "Agency".$delimiter."Advertiser".$delimiter."Campaign".$delimiter."Campaign ID".$delimiter."Remaining views".$delimiter;
    	echo "Start Date".$delimiter."End Date".$delimiter,"Target".$delimiter."Views".$delimiter."Percentage\n";
    	
    	while ($row_banners = phpAds_dbFetchArray($res_banners))
    	{
    		echo $row_banners['agency'].$delimiter;
    		echo $row_banners['advertiser'].$delimiter;
    		echo $row_banners['campaign'].$delimiter;
    		echo $row_banners['campaignid'].$delimiter;
    		echo $row_banners['remaining_views'].$delimiter;
    		//$total_views = phpAds_getAdViewsTotal($row_banners['campaignid']);
    		echo $row_banners['start_date'].$delimiter;
    		echo $row_banners['end_date'].$delimiter;
    		echo $row_banners['target'].$delimiter;
            echo $row_banners['views'].$delimiter;
            echo $row_banners['ratio'];
            //printf ('%0.2f', (($row_banners['views'] / $row_banners['target']) * 100));
            echo "%"."\n";
            
    	}
    }

}

?>